@@ -1,8 +1,7 @@
-/**
- * This file is part of TelepathyQt
+/*
+ * This file is part of TelepathyQt4
  *
- * @copyright Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
- * @license LGPL 2.1
+ * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,12 +18,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef _TelepathyQt_examples_accounts_accounts_window_h_HEADER_GUARD_
-#define _TelepathyQt_examples_accounts_accounts_window_h_HEADER_GUARD_
+#ifndef _TelepathyQt4_examples_accounts_accounts_window_h_HEADER_GUARD_
+#define _TelepathyQt4_examples_accounts_accounts_window_h_HEADER_GUARD_
 
 #include <QMainWindow>
 
-#include <TelepathyQt/Types>
+#include <TelepathyQt4/Types>
 
 namespace Tp {
 class PendingOperation;
@@ -43,7 +42,7 @@ public:
 
 private Q_SLOTS:
     void onAMReady(Tp::PendingOperation *);
-    void onNewAccount(const Tp::AccountPtr &);
+    void onAccountCreated(const QString &);
 
 private:
     void setupGui();
